==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/ronportal/jidelna/pohybynauctubrowser.php <==
<?php

/**
 * Seznam pohybu na uctech pro vybraneho stravnika
 */

namespace RonPortal\Jidelna;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class PohybyNaUctuBrowser extends RonPortalBrowser
{
    var $soucet;

    function __construct($database)
    {
        parent::__construct($database, 'pohybynauctu');

        $this->title = TextManager::_('Pohyby_na_uctu');
        $this ->code = 'browserpohybynauctu';
        $this ->showFooter = true;

        // definice dotazu a hlavicky
        $this ->sqlSelectPart = 'PohybNaUctu.DatumCasPohybu, TypPohybu.Popis, PohybNaUctu.Castka, PohybNaUctu.PopisPohybu';
        $this->sqlFromPart = 'PohybNaUctu, TypPohybu';
        $this->sqlWherePart =
            'TypPohybu.Kod=PohybNaUctu.TypPohybu';

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.DatumCasPohybu', 0)
            ->setCode('col-datumcas')
            ->setHeaderText('Datum_a_cas') ->setFormat('datetime') ->setOrdering(1);
        $this->defaultSort = 1;
        $this->primaryField = 0;

        $this->addField()
            ->setSqlFieldName('TypPohybu.Popis', 1)
            ->setCode('col-typpohybu')
            ->setHeaderText('Typ_pohybu') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.Castka', 2)
            ->setCode('col-castka')
            ->setHeaderText('Castka') ->setFormat('curr') ->setAlign('right') ->setOrdering(1);

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.PopisPohybu', 3)
            ->setCode('col-popis')
            ->setHeaderText('Popis') ->setOrdering(1);

        $this->soucet = 0;

        $this ->filterFormAppCode = 'JIDELNA';
        $this ->filterFormRights = 'prohl_jidelna';
        $this ->filterFormVcetneExternich = true;
    }


    function setFilterForm()
    {
        parent::setFilterForm();
        $this ->filterForm ->nastavAkciGet('pohybynauctu');
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        return new SqlStatement(
            'PohybNaUctu.DatumCasPohybu >= ' . $params ->addParameter($this ->database ->dateToParam($this ->filterForm ->vybraneObdobiOd)) .
            ' AND PohybNaUctu.DatumCasPohybu <= ' . $params ->addParameter($this ->database ->timestampToParam(DateUtils::endOfTheDay($this ->filterForm ->vybraneObdobiDo))) .
            ' AND PohybNaUctu.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND PohybNaUctu.OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND PohybNaUctu.DatumNastupu = ' . $params->addParameter($this ->database ->dateToParam($this ->filterForm->vybranaOsobaDatumNastupu)),
            $params);
    }


    function renderLine($values, $className, $rowNumber, $edit = false)
    {
        parent::renderLine($values, $className, $rowNumber, $edit);

        $this->soucet += $values[2];
    }

    function renderTableFooter()
    {
        $this->renderLine([null, TextManager::_('Celkem'), $this->soucet, ''], 'browserfooter', 0, false);
    }


    function renderCursor($cursor)
    {
        $this->soucet = 0;

        parent::renderCursor($cursor);
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/ronportal/jidelna/pohybynauctubrowser.php <==
<?php

/**
 * Seznam pohybu na uctech pro vybraneho stravnika
 */

namespace RonPortal\Jidelna;

use Ron\DateUtils;
use Ron\DB\SqlStatement;
use Ron\TextManager;
use RonPortal\Controls\RonPortalBrowser;


class PohybyNaUctuBrowser extends RonPortalBrowser
{
    function __construct($database)
    {
        parent::__construct($database, 'pohybynauctu');

        $this->title = TextManager::_('Pohyby_na_uctu');
        $this ->code = 'browserpohybynauctu';
        $this ->showFooter = true;

        // definice dotazu a hlavicky
        $this->sqlFromPart = 'PohybNaUctu, TypPohybu';
        $this->sqlWherePart =
            'TypPohybu.Kod=PohybNaUctu.TypPohybu';

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.DatumCasPohybu')
            ->setCode('col-datumcas')
            ->setHeaderText('Datum_a_cas') ->setFormat('datetime') ->setOrdering(1);
        $this->defaultSort = 'col-datumcas';
        $this->primaryField = 0;

        $this->addField()
            ->setSqlFieldName('TypPohybu.Popis')
            ->setCode('col-typpohybu')
            ->setHeaderText('Typ_pohybu') ->setOrdering(1)
            ->setFooter(TextManager::_('Celkem'));

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.Castka')
            ->setCode('col-castka')
            ->setHeaderText('Castka') ->setFormat('curr') ->setAlign('right') ->setOrdering(1)
            ->setShowSum(true);

        $this->addField()
            ->setSqlFieldName('PohybNaUctu.PopisPohybu')
            ->setCode('col-popis')
            ->setHeaderText('Popis') ->setOrdering(1);

        $this ->filterFormAppCode = 'JIDELNA';
        $this ->filterFormRights = 'prohl_jidelna';
        $this ->filterFormVcetneExternich = true;
        $this ->filterFormUseGet = true;
    }

    function setFilterForm()
    {
        parent::setFilterForm();
        $this ->filterForm ->addFilter(new StavUctuFilter($this ->filterForm));
    }


    function getSQLFilter()
    {
        $params = $this ->database ->createParameters();

        return new SqlStatement(
            'PohybNaUctu.DatumCasPohybu >= ' . $params ->addDateParameter($this ->filterForm ->vybraneObdobiOd) .
            ' AND PohybNaUctu.DatumCasPohybu <= ' . $params ->addTimestampParameter(DateUtils::endOfTheDay($this ->filterForm ->vybraneObdobiDo)) .
            ' AND PohybNaUctu.RC = ' . $params->addParameter($this ->filterForm ->vybranaOsobaRC) .
            ' AND PohybNaUctu.OsobniCislo = ' . $params->addParameter($this ->filterForm ->vybranaOsobaOsobniCislo) .
            ' AND PohybNaUctu.DatumNastupu = ' . $params->addDateParameter($this ->filterForm->vybranaOsobaDatumNastupu),
            $params);
    }
}
